@@ -4,11 +4,11 @@
 # later version.  See http://www.gnu.org/copyleft/lgpl.html for the full text
 # of the license.
 
-__author__ = 'Iain Lane'
-__copyright__ = '''
+__author__ = "Iain Lane"
+__copyright__ = """
 (c) 2013 Canonical Ltd.
 (c) 2017 - 2022 Martin Pitt <martin@piware.de>
-'''
+"""
 
 import shutil
 import subprocess
@@ -19,15 +19,15 @@ from pathlib import Path
 import dbusmock
 
 # timedatectl keeps changing its CLI output
-TIMEDATECTL_NTP_LABEL = '(NTP enabled|synchronized|systemd-timesyncd.service active)'
+TIMEDATECTL_NTP_LABEL = "(NTP enabled|synchronized|systemd-timesyncd.service active)"
 
-have_timedatectl = shutil.which('timedatectl')
+have_timedatectl = shutil.which("timedatectl")
 
 
-@unittest.skipUnless(have_timedatectl, 'timedatectl not installed')
-@unittest.skipUnless(Path('/run/systemd/system').exists(), '/run/systemd/system does not exist')
+@unittest.skipUnless(have_timedatectl, "timedatectl not installed")
+@unittest.skipUnless(Path("/run/systemd/system").exists(), "/run/systemd/system does not exist")
 class TestTimedated(dbusmock.DBusTestCase):
-    '''Test mocking timedated'''
+    """Test mocking timedated"""
 
     @classmethod
     def setUpClass(cls):
@@ -35,13 +35,8 @@ class TestTimedated(dbusmock.DBusTestCase):
         cls.dbus_con = cls.get_dbus(True)
 
     def setUp(self):
-        (self.p_mock, _) = self.spawn_server_template(
-            'timedated',
-            {},
-            stdout=subprocess.PIPE)
-        self.obj_timedated = self.dbus_con.get_object(
-            'org.freedesktop.timedate1',
-            '/org/freedesktop/timedate1')
+        (self.p_mock, _) = self.spawn_server_template("timedated", {}, stdout=subprocess.PIPE)
+        self.obj_timedated = self.dbus_con.get_object("org.freedesktop.timedate1", "/org/freedesktop/timedate1")
 
     def tearDown(self):
         if self.p_mock:
@@ -50,42 +45,40 @@ class TestTimedated(dbusmock.DBusTestCase):
             self.p_mock.wait()
 
     def run_timedatectl(self):
-        return subprocess.check_output(['timedatectl'],
-                                       universal_newlines=True)
+        return subprocess.check_output(["timedatectl"], universal_newlines=True)
 
     def test_default_timezone(self):
         out = self.run_timedatectl()
         # timedatectl doesn't get the timezone offset information over dbus so
         # we can't mock that.
-        self.assertRegex(out, 'Time *zone: Etc/Utc')
+        self.assertRegex(out, "Time *zone: Etc/Utc")
 
     def test_changing_timezone(self):
-        self.obj_timedated.SetTimezone('Africa/Johannesburg', False)
+        self.obj_timedated.SetTimezone("Africa/Johannesburg", False)
         out = self.run_timedatectl()
         # timedatectl doesn't get the timezone offset information over dbus so
         # we can't mock that.
-        self.assertRegex(out, 'Time *zone: Africa/Johannesburg')
+        self.assertRegex(out, "Time *zone: Africa/Johannesburg")
 
     def test_default_ntp(self):
         out = self.run_timedatectl()
-        self.assertRegex(out, f'{TIMEDATECTL_NTP_LABEL}: yes')
+        self.assertRegex(out, f"{TIMEDATECTL_NTP_LABEL}: yes")
 
     def test_changing_ntp(self):
         self.obj_timedated.SetNTP(False, False)
         out = self.run_timedatectl()
-        self.assertRegex(out, f'{TIMEDATECTL_NTP_LABEL}: no')
+        self.assertRegex(out, f"{TIMEDATECTL_NTP_LABEL}: no")
 
     def test_default_local_rtc(self):
         out = self.run_timedatectl()
-        self.assertRegex(out, 'RTC in local TZ: no')
+        self.assertRegex(out, "RTC in local TZ: no")
 
     def test_changing_local_rtc(self):
         self.obj_timedated.SetLocalRTC(True, False, False)
         out = self.run_timedatectl()
-        self.assertRegex(out, 'RTC in local TZ: yes')
+        self.assertRegex(out, "RTC in local TZ: yes")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # avoid writing to stderr
-    unittest.main(testRunner=unittest.TextTestRunner(
-        stream=sys.stdout))
+    unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout))
